@@ -2,4 +2,4 @@
 
 from .compiler import PatternCompiler
 
-__all__ = ['PatternCompiler']
\ No newline at end of file
+__all__ = ["PatternCompiler"]
