@@ -3,8 +3,8 @@ Stream processing module for strataregula.
 Handles chunked data processing, real-time streaming, and memory-efficient large file processing.
 """
 
-from .processor import StreamProcessor, ChunkProcessor
-from .chunker import Chunker, ChunkConfig
+from .chunker import ChunkConfig, Chunker
+from .processor import ChunkProcessor, StreamProcessor
 
-__all__ = ["StreamProcessor", "ChunkProcessor", "Chunker", "ChunkConfig"]
-__version__ = "0.0.1"
\ No newline at end of file
+__all__ = ["ChunkConfig", "ChunkProcessor", "Chunker", "StreamProcessor"]
+__version__ = "0.0.1"
